@@ -2,11 +2,8 @@ from abc import ABCMeta, abstractmethod
 
 import numpy as np
 
-TABLE_NAME = 'cache_table'
-TABLE_NAME_SEQ = 'cache_table_sequence'
 
-
-class ScalarStorage(metaclass=ABCMeta):
+class CacheStorage(metaclass=ABCMeta):
     """
     BaseStorage for scalar data.
     """
@@ -34,6 +31,12 @@ class ScalarStorage(metaclass=ABCMeta):
     @abstractmethod
     def update_state(self, keys): pass
 
+    @abstractmethod
+    def get_old_access(self, count): pass
+
+    @abstractmethod
+    def get_old_create(self, count): pass
+
     @abstractmethod
     def count(self): pass
 
